/*
 *  Copyright (c) 2006 Boudewijn Rempt <boud@valdyas.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#include "kis_mask_shape.h"

#include <QPainter>
#include "KoViewConverter.h"

#include <kis_types.h>
#include <kis_mask.h>

class KisMaskShape::Private {

public:

    KisMaskSP mask;
};


KisMaskShape::KisMaskShape(KoShapeContainer * parent, KisMaskSP mask )
    : m_d( new Private() )
{
    m_d->mask = mask;

    setParent( parent );
    setShapeId( KIS_MASK_SHAPE_ID );
}

KisMaskShape::~KisMaskShape()
{
    delete m_d;
}


KisMaskSP KisMaskShape::mask()
{
    return m_d->mask;
}

void KisMaskShape::paint(QPainter &painter, const KoViewConverter &converter)
{
   Q_UNUSED( painter );
   Q_UNUSED( converter );
   // Do nothing! Masks don't paint on QPainters
}

